#!/usr/bin/perl

###############################################################################
# 
# phorSale - An eCommerce application for PHP and mySQL.
# Copyright (C) 2001 Michael Kmiec <mike@shifter.org>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################


###############################################################################
#
# The following code is based largely on the CyberCash MCK implementation perl scripts.
#
# This code takes submitted information, sends it to the CyberCash
# Cash Register server, and returns the response as a key-value string
# delimited with pipes ("|") for parsing by the caller.
#
###############################################################################
require 5.005;

BEGIN 
{
# the next line may be needed if using IIS or if the CGI is not in the same
# directory as the Perl modules.
push(@INC, '/home/phorSale/cgi');
push(@INC, '/home/phorSale/cgi/');
}

use CCMckLib3_2 qw($serviceType $MCKversion %Config InitConfig CCDebug CCError);

use CCMckDirectLib3_2 qw(doDirectPayment);

use CCMckErrno3_2 qw(MCKGetErrorMessage $E_NoErr);

use CCMerchantCustom qw(GenerateOrderId);

use CGI qw(:standard remote_addr); 

use CCMerchantTest qw(LogNotification);

###############################################################################
# Initialize some data blocks and values...
###############################################################################

$OS = 'UNIX';

$progdir = '/home/phorSale/cgi/';

if ($OS eq 'NT') {
   $ConfigFile =  $progdir . "conf\\merchant_conf";
}
else {
   $ConfigFile =  $progdir . "conf/merchant_conf";
}
 
# serviceTypes: "fp-cr" = Cash Register & Fraud Patrol; "cr" = Cash Register only; "fp" = Fraud Patrol only
$serviceType = "cr";

# Initialize the Global Configuration array in CCMckLib3_2...

($status) = &InitConfig($ConfigFile);

if ($status != $E_NoErr) 
{
    # rudimentary error handling shown here...

    $errmsg = &MCKGetErrorMessage($status);

    print "Error: $errmsg\n";

    die("$0: $errmsg.\n");
}

# main code starts here...

# This will log to the debug log if configuration has a valid log level
&CCDebug("\nCyberCash.cgi: entering ...\n");

# values read from the configuration file
$cybercashId = $Config{"CYBERCASH_ID"};
$ccpsHost    = $Config{"CCPS_HOST"};

# start building the name-value (NV) array sent to CyberCash...
$paymentNVList{'mo.cybercash-id'} = $cybercashId;   # CyberCash ID provided
                                                    # during registration

# This is the CyberCash CGI that will process your payment--this should NOT be
# altered.
$script = "directcardpayment.cgi";

# We instantiate a new CGI object
$query = new CGI();

# get the order ID
$orderID = $query->param('mo.order-id');

# the fields below are collected in the HTML form with the same
# name as that passed to CyberCash using the MessageBlock API.
# these are the recommended and mandatory fields for using the
# CashRegister. However this may change in the future.
$paymentNVList{'mo.order-id'}      = $orderID;
$paymentNVList{'mo.price'}         = $query->param('mo.price');

$paymentNVList{'cpi.card-number'}  = $query->param('cpi.card-number');
$paymentNVList{'cpi.card-exp'}     = $query->param('cpi.card-exp');
$paymentNVList{'cpi.card-name'}    = $query->param('cpi.card-name'); 
$paymentNVList{'cpi.card-address'} = $query->param('cpi.card-address');
$paymentNVList{'cpi.card-city'}    = $query->param('cpi.card-city');
$paymentNVList{'cpi.card-state'}   = $query->param('cpi.card-state');
$paymentNVList{'cpi.card-zip'}     = $query->param('cpi.card-zip');
$paymentNVList{'cpi.card-country'} = $query->param('cpi.card-country');
$paymentNVList{'cpi.card-type'}    = $query->param('cpi.card-type');

# done with setting associative array values...
&CCDebug("CyberCash.cgi: added all payment name-value args...\n");

$paymentURL = "$ccpsHost$script";

&CCDebug("CyberCash.cgi: payment URL $paymentURL\n");

# send the message to the CyberCash CashRegister server...
($POPref, $tokenListref) = &doDirectPayment($paymentURL, \%paymentNVList);

&CCDebug("CyberCash.cgi: returned from doDirectPayment()\n");

# At this point we should have received a response from the
# CyberCash server. However it is possible during early integration to
# receive errors from the MCK if the latter is not configured correctly.

%POP       = %$POPref;

#Log Payment results here...

%tokenList = %$tokenListref;	

$POPstr = $tokenList{'POP'};
($logStatus, $logCode) = &LogNotification($POPstr);

&CCDebug("CyberCash.cgi: generating response string\n");

# create the response string to send back
print header('text/plain');

foreach $key (keys (%POP)) {
    
    print "$key=$POP{$key}|";
    &CCDebug("CyberCash.cgi: $key=$POP{$key}\n");

}


exit 0;
